import{l as D,D as N,m as M,A as x,ax as H,z as L,aH as T,f as c,E as C,d as E,Q as R,c as l,e as u,w as n,O as U,ac as _,j as y,i as w,a0 as j,u as V,M as Q,g as b,t as f,az as q,X as P,af as G}from"./index-bf0eaf20.js";import{M as J}from"./ItemContextMenu.vue_vue_type_style_index_0_scoped_d4387993_lang-b7e5044b.js";import{V as K}from"./VCard-97256dbd.js";import{e as W,g as Z,c as ee}from"./VMenu-71b97cab.js";import{m as te,V as g}from"./VCheckboxBtn-f3296201.js";import{b as se,u as ae,c as B}from"./VLabel-e07a3413.js";import{c as oe,V as le,C as ie,D as I,s as ne}from"./VListItem-223b492d.js";import{_ as re}from"./_plugin-vue_export-helper-c27b6911.js";const ue=D({...se(),...N(te(),["inline"])},"VCheckbox"),ce=M()({name:"VCheckbox",inheritAttrs:!1,props:ue(),emits:{"update:modelValue":t=>!0,"update:focused":t=>!0},setup(t,m){let{attrs:s,slots:a}=m;const o=x(t,"modelValue"),{isFocused:d,focus:i,blur:e}=ae(t),v=H(),p=L(()=>t.id||`checkbox-${v}`);return oe(()=>{const[r,h]=T(s),S=B.filterProps(t),X=g.filterProps(t);return c(B,C({class:["v-checkbox",t.class]},r,S,{modelValue:o.value,"onUpdate:modelValue":k=>o.value=k,id:p.value,focused:d.value,style:t.style}),{...a,default:k=>{let{id:$,messagesId:A,isDisabled:F,isReadonly:O,isValid:Y}=k;return c(g,C(X,{id:$.value,"aria-describedby":A.value,disabled:F.value,readonly:O.value},h,{error:Y.value===!1,modelValue:o.value,"onUpdate:modelValue":z=>o.value=z,onFocus:i,onBlur:e}),a)}})}),{}}}),me=D({disabled:Boolean,modelValue:{type:Boolean,default:null},...W()},"VHover"),de=M()({name:"VHover",props:me(),emits:{"update:modelValue":t=>!0},setup(t,m){let{slots:s}=m;const a=x(t,"modelValue"),{runOpenDelay:o,runCloseDelay:d}=Z(t,i=>!t.disabled&&(a.value=i));return()=>{var i;return(i=s.default)==null?void 0:i.call(s,{isHovering:a.value,props:{onMouseenter:o,onMouseleave:d}})}}}),pe=["model-value"],fe={key:0},ve={key:1},ye={key:2},he=E({__name:"PanelviewItemCompact",props:{item:{},size:{default:200},isSelected:{type:Boolean,default:!1},showCheckboxes:{type:Boolean,default:!1},permanentOverlay:{type:Boolean,default:!1}},emits:["menu","click","play","select"],setup(t,{emit:m}){const s=t,a=m,o=function(e){if(s.showCheckboxes)return;const v="clientX"in e?e.clientX:e.touches[0].clientX,p="clientY"in e?e.clientY:e.touches[0].clientY;a("menu",s.item,v,p)},d=function(e){if(s.showCheckboxes){a("select",s.item,!s.isSelected);return}a("click",s.item,e.clientX,e.clientY)},i=function(e){s.showCheckboxes||a("play",s.item,e.clientX,e.clientY)};return(e,v)=>{const p=R("hold");return l(),u(de,null,{default:n(({isHovering:r,props:h})=>[U((l(),u(K,C(h,{class:{"on-hover":r},elevation:r?3:0,onClick:d,onContextmenu:_(o,["right","prevent"])}),{default:n(()=>[e.showCheckboxes?(l(),u(ee,{key:0,"model-value":e.showCheckboxes,contained:"",scrim:e.isSelected?e.$vuetify.theme.current.dark?"rgba(0,0,0,.75)":"rgba(255,255,255,.75)":"#ffffff00"},{default:n(()=>[c(ce,{class:"panel-item-checkbox",ripple:!1,"model-value":e.isSelected},null,8,["model-value"])]),_:1},8,["model-value","scrim"])):y("",!0),c(J,{item:e.item},null,8,["item"]),w("div",{class:j(e.$vuetify.theme.current.dark?"paneldetails-dark":"paneldetails"),"model-value":r||e.$vuetify.display.mobile||e.permanentOverlay},[c(le,{variant:"text",slim:"",tile:"",density:"compact",class:"panel-item-details"},{default:n(()=>[c(ie,null,{default:n(()=>[e.item.media_type==V(Q).FOLDER?(l(),b("span",fe,[w("span",null,f(V(q)(e.item,e.$t)),1)])):(l(),b("span",ve,f(e.item.name),1)),"version"in e.item&&e.item.version?(l(),b("span",ye," - "+f(e.item.version),1)):y("",!0)]),_:1}),"artists"in e.item&&e.item.artists?(l(),u(I,{key:0,class:"line-clamp-1"},{default:n(()=>[P(f(V(G)(e.item.artists,1)),1)]),_:1})):"owner"in e.item&&e.item.owner?(l(),u(I,{key:1,class:"line-clamp-1"},{default:n(()=>[P(f(e.item.owner),1)]),_:1})):y("",!0)]),_:1})],10,pe),r||e.$vuetify.display.mobile?(l(),u(ne,{key:1,icon:"mdi-play",color:"primary",fab:"",size:"small",style:{position:"absolute",right:"10px",bottom:"35px",opacity:"0.8"},onClick:_(i,["stop"])})):y("",!0)]),_:2},1040,["class","elevation"])),[[p,o]])]),_:1})}}});const Be=re(he,[["__scopeId","data-v-30d18934"]]);export{Be as P,ce as V,de as a};
