import{I as f}from"./ItemsListing-496384e5.js";import{d as v,a9 as b,r as l,o as h,b as a,P as I,ab as r,a as w,c as E,e as T,M as m,ap as n}from"./index-bf0eaf20.js";import"./ItemContextMenu.vue_vue_type_style_index_0_scoped_d4387993_lang-b7e5044b.js";import"./eventbus-b340f869.js";import"./VListItem-223b492d.js";import"./VLabel-e07a3413.js";import"./VList-21e2a257.js";import"./VCardText-8a9fa9c7.js";import"./VCard-97256dbd.js";import"./VMenu-71b97cab.js";import"./_plugin-vue_export-helper-c27b6911.js";import"./ListItem-b1725b5d.js";import"./Button-574f04d4.js";import"./PanelviewItemCompact-cb3303f4.js";import"./VCheckboxBtn-f3296201.js";import"./VSpacer-36b6f8a9.js";/* empty css              */import"./VAlert-e2b3a5a6.js";import"./Container-88f21350.js";import"./Toolbar-1985c49b.js";import"./VToolbar-219721ba.js";import"./VTextField-ad1ef579.js";import"./VVirtualScroll-837eb7b9.js";import"./VInfiniteScroll-71aa3856.js";import"./layout-8db27034.js";const Q=v({name:"Playlists",__name:"LibraryPlaylists",setup(A){const{t:u}=b(),c=l([]),o=l(!1),p=l([]),d=["name","name_desc","sort_name","sort_name_desc","timestamp_added","timestamp_added_desc","timestamp_modified","timestamp_modified_desc","last_played","last_played_desc","play_count","play_count_desc"],_=async function(t){if(t.refresh&&!o.value){for(a.startSync([m.PLAYLIST]),await n(250);a.syncTasks.value.length>0&&a.syncTasks.value.filter(e=>e.media_types.includes(m.PLAYLIST)).length!=0;)await n(500);await n(500)}return o.value=!1,await a.getLibraryPlaylists(t.favoritesOnly||void 0,t.search,t.limit,t.offset,t.sortBy)};h(()=>{const t=[];for(const s of Object.values(a.providers).filter(i=>i.available&&i.supported_features.includes(I.PLAYLIST_CREATE)))t.push({label:"create_playlist_on",labelArgs:[s.name],action:()=>{y(s.instance_id)},icon:"mdi-playlist-plus"});t.length&&p.value.push({label:"create_playlist_on",icon:"mdi-playlist-plus",subItems:t});const e=a.subscribe_multi([r.MEDIA_ITEM_ADDED,r.MEDIA_ITEM_UPDATED,r.MEDIA_ITEM_DELETED],s=>{var i;(i=s.object_id)!=null&&i.startsWith("library://playlist")&&(o.value=!0)});w(e)});const y=async function(t){const e=prompt(u("new_playlist_name"));e&&await a.createPlaylist(e,t).then(()=>location.reload()).catch(s=>alert(s))};return(t,e)=>(E(),T(f,{itemtype:"playlists",items:c.value,"show-duration":!1,"show-provider":!0,"show-favorites-only-filter":!0,"load-paged-data":_,"show-library":!0,"sort-keys":d,"update-available":o.value,title:t.$t("playlists"),"allow-key-hooks":!0,"show-search-button":!0,"extra-menu-items":p.value,icon:"mdi-playlist-play","restore-state":!0},null,8,["items","update-available","title","extra-menu-items"]))}});export{Q as default};
