import{d as m,a9 as l,r as u,z as c,W as a,c as f,g as d,f as h,b as w}from"./index-bf0eaf20.js";import{I as b}from"./ItemsListing-496384e5.js";import"./ItemContextMenu.vue_vue_type_style_index_0_scoped_d4387993_lang-b7e5044b.js";import"./eventbus-b340f869.js";import"./VListItem-223b492d.js";import"./VLabel-e07a3413.js";import"./VList-21e2a257.js";import"./VCardText-8a9fa9c7.js";import"./VCard-97256dbd.js";import"./VMenu-71b97cab.js";import"./_plugin-vue_export-helper-c27b6911.js";import"./ListItem-b1725b5d.js";import"./Button-574f04d4.js";import"./PanelviewItemCompact-cb3303f4.js";import"./VCheckboxBtn-f3296201.js";import"./VSpacer-36b6f8a9.js";/* empty css              */import"./VAlert-e2b3a5a6.js";import"./Container-88f21350.js";import"./Toolbar-1985c49b.js";import"./VToolbar-219721ba.js";import"./VTextField-ad1ef579.js";import"./VVirtualScroll-837eb7b9.js";import"./VInfiniteScroll-71aa3856.js";import"./layout-8db27034.js";const M=m({__name:"BrowseView",props:{path:{}},setup(s){const t=s,{t:e}=l(),i=u(!1),p=c(()=>!t.path||t.path=="root"?e("browse"):a("bp6")?e("browse")+" | "+t.path:a("bp3")?t.path:e("browse")),n=async function(o){const r=await w.browse(o.offset,o.limit,t.path);return i.value=r.total!=null,r};return(o,r)=>(f(),d("section",null,[h(b,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-paged-data":n,"sort-keys":i.value?["original","name","name_desc"]:["original"],title:p.value,path:o.path,"allow-key-hooks":!0,icon:"mdi-folder-outline","no-server-side-sorting":!0},null,8,["sort-keys","title","path"])]))}});export{M as default};
