import{I as f}from"./ItemsListing-496384e5.js";import{d as h,a9 as b,r as d,o as v,b as a,ab as r,a as I,c as g,e as D,M as n,ap as l,ah as E,V as T}from"./index-bf0eaf20.js";import"./ItemContextMenu.vue_vue_type_style_index_0_scoped_d4387993_lang-b7e5044b.js";import"./eventbus-b340f869.js";import"./VListItem-223b492d.js";import"./VLabel-e07a3413.js";import"./VList-21e2a257.js";import"./VCardText-8a9fa9c7.js";import"./VCard-97256dbd.js";import"./VMenu-71b97cab.js";import"./_plugin-vue_export-helper-c27b6911.js";import"./ListItem-b1725b5d.js";import"./Button-574f04d4.js";import"./PanelviewItemCompact-cb3303f4.js";import"./VCheckboxBtn-f3296201.js";import"./VSpacer-36b6f8a9.js";/* empty css              */import"./VAlert-e2b3a5a6.js";import"./Container-88f21350.js";import"./Toolbar-1985c49b.js";import"./VToolbar-219721ba.js";import"./VTextField-ad1ef579.js";import"./VVirtualScroll-837eb7b9.js";import"./VInfiniteScroll-71aa3856.js";import"./layout-8db27034.js";const X=h({name:"Radios",__name:"LibraryRadios",setup(w){const{t:s}=b(),u=d([]),i=d(!1),c=["name","name_desc","sort_name","sort_name_desc","timestamp_added","timestamp_added_desc","last_played","last_played_desc","play_count","play_count_desc"];v(()=>{const t=a.subscribe_multi([r.MEDIA_ITEM_ADDED,r.MEDIA_ITEM_UPDATED,r.MEDIA_ITEM_DELETED],e=>{var o;(o=e.object_id)!=null&&o.startsWith("library://radio")&&(i.value=!0)});I(t)});const _=async function(t){if(t.refresh&&!i.value){for(a.startSync([n.RADIO]),await l(250);a.syncTasks.value.length>0&&a.syncTasks.value.filter(e=>e.media_types.includes(n.RADIO)).length!=0;)await l(500);await l(500)}return i.value=!1,await a.getLibraryRadios(t.favoritesOnly||void 0,t.search,t.limit,t.offset,t.sortBy)},y=async function(){const t=prompt(s("enter_url"));if(t){if(!(t!=null&&t.startsWith("http"))){alert(s("invalid_input"));return}a.getItem(n.RADIO,t,"builtin").then(e=>{var p;const o=prompt(s("enter_name"),e.name);e.name=o||e.name,delete e.sort_name;const m=prompt(s("image_url"),(p=e.metadata.images)!=null&&p.length?e.metadata.images[0].path:"");m&&(e.metadata.images=[{type:E.THUMB,path:m,provider:"builtin",remotely_accessible:!0}]),a.addItemToLibrary(e).then(()=>T.go(0))}).catch(e=>alert(e))}};return(t,e)=>(g(),D(f,{itemtype:"radios",items:u.value,"show-duration":!1,"show-provider":!1,"show-favorites-only-filter":!0,"load-paged-data":_,"sort-keys":c,"update-available":i.value,title:t.$t("radios"),"show-search-button":!0,"allow-key-hooks":!0,"extra-menu-items":[{label:"add_url_item",labelArgs:[],action:()=>{y()},icon:"mdi-playlist-plus"}],icon:"mdi-access-point","restore-state":!0},null,8,["items","update-available","title","extra-menu-items"]))}});export{X as default};
